﻿/// <reference path="../../../Resources/TypeDefinitions/jquery/jquery.d.ts"/>
/// <reference path="../../../Resources/TypeDefinitions/knockout/knockout.d.ts"/>
/// <reference path="../../../rubbish.ts"/>

var CreateOrEditFeedPageViewModel = (function () {
    function CreateOrEditFeedPageViewModel(input) {
        var _this = this;
        var coalesce = function (arg, defaultValue) {
            return arg !== undefined ? arg : defaultValue;
        };

        this.feedId = input.feedId || null;
        this.feedName = ko.observable(input.feedName || '');
        this.feedDescription = ko.observable(input.feedDescription || '');
        this.feedType = ko.observable(input.feedType || 'N');
        this.diskPath = ko.observable(input.diskPath || '');
        this.dropPath = ko.observable(input.dropPath || '');
        this.apiKey = ko.observable(input.apiKey || '');
        this.packageStoreConfig = ko.observable(input.packageStoreConfig || '');
        this.isActive = ko.observable(coalesce(input.isActive, true));
        this.isCached = ko.observable(coalesce(input.isCached, true));
        this.symbolServerEnabled = ko.observable(coalesce(input.symbolServerEnabled, true));
        this.stripSymbolsEnabled = ko.observable(coalesce(input.stripSymbolsEnabled, true));
        this.showPackageStoreConfig = input.showPackageStoreConfig || false;
        this.isLegacy = input.isLegacy || false;
        this.saveUrl = input.saveUrl;

        this.isNpm = ko.computed(function () {
            return _this.feedType() == 'P';
        });
        this.isBower = ko.computed(function () {
            return _this.feedType() == 'B';
        });
        this.isMaven = ko.computed(function () {
            return _this.feedType() == 'M';
        });
        this.allowSymbolFeatures = ko.computed(function () {
            return _this.feedType() == 'N';
        });
        this.errorText = ko.observable(null);

        this.isInvalid = ko.observable(false);
        this.showFeedNameRequired = ko.computed(function () {
            return _this.isInvalid() && !_this.feedName();
        });

        this.showBulkImportPath = ko.computed(function () {
            return !_this.isLegacy && !_this.isBower() && !_this.isMaven();
        });
        this.showNuGetAPIKey = ko.computed(function () {
            return !_this.isNpm() && !_this.isBower() && !_this.isMaven();
        });
        this.reallyShowPackageStoreConfig = ko.computed(function () {
            return _this.showPackageStoreConfig && !_this.isNpm() && !_this.isBower() && !_this.isMaven();
        });
    }
    CreateOrEditFeedPageViewModel.prototype.saveClick = function () {
        var _this = this;
        if (!this.feedName()) {
            this.isInvalid(true);
            return;
        } else {
            this.isInvalid(false);
        }

        $.ajax({
            url: this.saveUrl,
            data: {
                feedId: this.feedId,
                feedName: this.feedName(),
                feedDescription: this.feedDescription(),
                feedType: this.feedType(),
                diskPath: this.diskPath(),
                dropPath: this.dropPath(),
                apiKey: this.apiKey(),
                packageStoreConfig: this.packageStoreConfig(),
                isActive: this.isActive(),
                isCached: this.isCached(),
                symbolServerEnabled: this.symbolServerEnabled(),
                stripSymbolsEnabled: this.stripSymbolsEnabled()
            },
            type: 'POST',
            success: function (response) {
                if (response.feedUrl) {
                    // success
                    window.parent.location.href = response.feedUrl;
                } else if (response.errorText) {
                    // failure
                    _this.errorText(response.errorText);
                }
            }
        });
    };

    CreateOrEditFeedPageViewModel.prototype.cancelClick = function () {
        this.closeModal();
    };

    CreateOrEditFeedPageViewModel.prototype.closeModal = function () {
        if (parent.jQuery && parent.jQuery.fn.inedojq_frameddialog)
            parent.jQuery('iframe[name="' + window.name + '"]').trigger('dialogclose', { refreshOnClose: false }).attr('src', 'about:blank').remove();
    };
    return CreateOrEditFeedPageViewModel;
})();
