﻿/// <reference path="../../Resources/TypeDefinitions/jquery/jquery.d.ts"/>
/// <reference path="../../Resources/TypeDefinitions/knockout/knockout.d.ts"/>
/// <reference path="../../Resources/TypeDefinitions/inedojq/inedojq_frameddialog.d.ts"/>
/// <reference path="../../rubbish.ts"/>

var NuGetPackageVersionPageViewModel = (function () {
    function NuGetPackageVersionPageViewModel(input) {
        var _this = this;
        this.feedName = input.feedName;
        this.packageId = input.packageId;
        this.packageVersion = input.packageVersion;
        this.getDetailsUrl = input.getDetailsUrl;
        this.getVersionsUrl = input.getVersionsUrl;
        this.setListedUrl = input.setListedUrl;
        this.feedType = input.feedType;
        this.details = ko.observable();

        this.friendlyTitle = ko.computed(function () {
            if (_this.details())
                return _this.details().title || _this.packageId;
            else
                return _this.packageId;
        });

        this.allVersions = ko.observable(new Array());

        this.iconUrl = ko.computed(function () {
            var details = _this.details();
            if (details && details.iconUrl)
                return "url('" + details.iconUrl + "')";
            else
                return null;
        });

        this.iconCss = ko.computed(function () {
            var details = _this.details();
            if (details)
                return $.extend({ remote: !details.isLocal && !details.isCached }, _this.feedType);
            else
                return _this.feedType;
        });

        this.showAllVersions = ko.observable(false);

        this.topVersions = ko.computed(function () {
            var all = _this.allVersions();
            if (all.length <= 5)
                return all;
            else
                return all.slice(0, 5);
        });

        this.remainingVersions = ko.computed(function () {
            var all = _this.allVersions();
            var top = _this.topVersions();

            if (all.length > top.length)
                return all.slice(top.length, all.length - top.length);
            else
                return new Array();
        });

        this.listButtonText = ko.computed(function () {
            var details = _this.details();
            return (details != null && details.isListed) ? 'Unlist Package' : 'List Package';
        });

        this.updateDetails();
    }
    NuGetPackageVersionPageViewModel.prototype.showSymbols = function () {
        $.inedojq_frameddialog(this.details().showSymbolsUrl);
    };

    NuGetPackageVersionPageViewModel.prototype.showStatistics = function () {
        $.inedojq_frameddialog(this.details().showStatisticsUrl);
    };

    NuGetPackageVersionPageViewModel.prototype.deletePackage = function () {
        $.inedojq_frameddialog(this.details().deletePackageUrl);
    };

    NuGetPackageVersionPageViewModel.prototype.pullPackage = function () {
        var _this = this;
        $.inedojq_frameddialog(this.details().pullPackageUrl, {
            dialogClose: function () {
                _this.updateDetails();
            }
        });
    };

    NuGetPackageVersionPageViewModel.prototype.listUnlistPackage = function () {
        var _this = this;
        $.ajax({
            url: this.setListedUrl,
            data: { feedName: this.feedName, packageId: this.packageId, packageVersion: this.packageVersion, listed: !this.details().isListed },
            type: 'POST',
            success: function () {
                _this.updateDetails();
            }
        });
    };

    NuGetPackageVersionPageViewModel.prototype.showAllVersionsClick = function () {
        this.showAllVersions(true);
    };

    NuGetPackageVersionPageViewModel.prototype.updateDetails = function () {
        var _this = this;
        $.ajax({
            url: this.getDetailsUrl,
            data: { feedName: this.feedName, packageId: this.packageId, packageVersion: this.packageVersion },
            type: 'POST',
            success: function (data) {
                _this.details(data);
                _this.updateVersions();
            }
        });
    };

    NuGetPackageVersionPageViewModel.prototype.updateVersions = function () {
        var _this = this;
        $.ajax({
            url: this.getVersionsUrl,
            data: { feedName: this.feedName, packageId: this.packageId, packageVersion: this.packageVersion },
            type: 'POST',
            success: function (data) {
                _this.allVersions(data);
            }
        });
    };
    return NuGetPackageVersionPageViewModel;
})();
