﻿/// <reference path="../../../Resources/TypeDefinitions/jquery/jquery.d.ts"/>
/// <reference path="../../../Resources/TypeDefinitions/knockout/knockout.d.ts"/>
/// <reference path="../../../rubbish.ts"/>
var PullMavenArtifactStatusPage;
(function (PullMavenArtifactStatusPage) {
    var VersionViewModel = (function () {
        function VersionViewModel(version, status) {
            var _this = this;
            this.version = version;
            this.status = ko.observable(status);

            this.statusImgUrl = ko.computed(function () {
                switch (_this.status()) {
                    case 'Success':
                        return '/Resources/Images/Icons/status-success.svg';
                    case 'Failed':
                        return '/Resources/Images/Icons/status-fail.svg';
                    default:
                    case 'NotApplicable':
                        return '/Resources/Images/Icons/status-na.svg';
                    case 'Pending':
                        return '/Resources/Images/Icons/status-pending.svg';
                    case 'Loading':
                        return '/Resources/Images/Icons/status-loading.gif';
                    case 'Warning':
                        return '/Resources/Images/Icons/status-warning.svg';
                }
            });

            this.statusText = ko.computed(function () {
                switch (_this.status()) {
                    case 'Success':
                        return 'Succeeded';
                    case 'Failed':
                        return 'Failed';
                    case 'NotApplicable':
                        return 'Not Applicable';
                    case 'Pending':
                        return 'Pending';
                    case 'Loading':
                        return 'Downloading';
                    case 'Warning':
                        return 'Warning';
                    default:
                        return '';
                }
            });
        }
        return VersionViewModel;
    })();

    var ViewModel = (function () {
        function ViewModel(input) {
            var _this = this;
            this.updateUrl = input.updateUrl;
            this.status = ko.observable(input.initialData.status);
            this.errorMessage = ko.observable(input.initialData.errorMessage);
            this.versions = ko.observableArray(input.initialData.versions.map(function (v) {
                return new VersionViewModel(v.version, v.status);
            }));
            this.succeeded = ko.computed(function () {
                return _this.status() == 'Success';
            });

            window.setTimeout(function () {
                return _this.update();
            }, 500);
        }
        ViewModel.prototype.update = function () {
            var _this = this;
            $.ajax({
                url: this.updateUrl,
                type: 'POST',
                success: function (data) {
                    _this.status(data.status);

                    var current = _this.versions();
                    if (current.length != data.versions.length) {
                        _this.versions(data.versions.map(function (v) {
                            return new VersionViewModel(v.version, v.status);
                        }));
                    } else {
                        for (var i = 0; i < data.versions.length; i++) {
                            for (var j = 0; j < current.length; j++) {
                                if (data.versions[i].version == current[j].version) {
                                    current[j].status(data.status);
                                    break;
                                }
                            }
                        }
                    }

                    window.setTimeout(function () {
                        return _this.update();
                    }, 500);
                }
            });
        };
        return ViewModel;
    })();

    function Init(input) {
        ko.applyBindings(new ViewModel(input));
    }
    PullMavenArtifactStatusPage.Init = Init;
})(PullMavenArtifactStatusPage || (PullMavenArtifactStatusPage = {}));
